Learn R Programming

whereport (version 0.1)

where_iata: IATA localization

Description

where_iata answers the question: "Where is located the airport with this IATA code?".

Usage

where_iata(IATA_code)

Arguments

IATA_code

a string or vector of strings containing the three letters IATA code(s)

Value

A dataframe containing IATA code, ICAO codes, Airport name, Location served, Time zone, and DST.

Some of the fields may be `na`.

Examples

Run this code
# NOT RUN {
where_iata("YVR")
where_iata(c("YVR","CHC"))

# }

Run the code above in your browser using DataLab