powered by
where_iata answers the question: "Where is located the airport with this IATA code?".
where_iata(IATA_code)
a string or vector of strings containing the three letters IATA code(s)
A dataframe containing IATA code, ICAO codes, Airport name, Location served, Time zone, and DST.
Some of the fields may be `na`.
# NOT RUN { where_iata("YVR") where_iata(c("YVR","CHC")) # }
Run the code above in your browser using DataLab